==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscDecyzjaSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class OdplatnoscDecyzjaSkladnikKey extends GenericDPSObject {
    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long decyzjaOOdplatnosciId;

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long odplatnoscId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDecyzjaOOdplatnosciId() {
        return decyzjaOOdplatnosciId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:40
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     *
     * @param decyzjaOOdplatnosciId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDecyzjaOOdplatnosciId(Long decyzjaOOdplatnosciId) {
        this.decyzjaOOdplatnosciId = decyzjaOOdplatnosciId;
    }

    /**
     * @return ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getOdplatnoscId() {
        return odplatnoscId;
    }

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     *
     * @param odplatnoscId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setOdplatnoscId(Long odplatnoscId) {
        this.odplatnoscId = odplatnoscId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscDecyzjaSkladnikKey other = (OdplatnoscDecyzjaSkladnikKey) that;
        return (this.getDecyzjaOOdplatnosciId() == null ? other.getDecyzjaOOdplatnosciId() == null : this.getDecyzjaOOdplatnosciId().equals(other.getDecyzjaOOdplatnosciId()))
            && (this.getOdplatnoscId() == null ? other.getOdplatnoscId() == null : this.getOdplatnoscId().equals(other.getOdplatnoscId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDecyzjaOOdplatnosciId() == null) ? 0 : getDecyzjaOOdplatnosciId().hashCode());
        result = prime * result + ((getOdplatnoscId() == null) ? 0 : getOdplatnoscId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", decyzjaOOdplatnosciId=").append(decyzjaOOdplatnosciId);
        sb.append(", odplatnoscId=").append(odplatnoscId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/OdplatnoscDecyzjaSkladnikKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class OdplatnoscDecyzjaSkladnikKey extends GenericDPSObject {
    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long decyzjaOOdplatnosciId;

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long odplatnoscId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDecyzjaOOdplatnosciId() {
        return decyzjaOOdplatnosciId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:45
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.DECYZJA_O_ODPLATNOSCI_ID
     *
     * @param decyzjaOOdplatnosciId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDecyzjaOOdplatnosciId(Long decyzjaOOdplatnosciId) {
        this.decyzjaOOdplatnosciId = decyzjaOOdplatnosciId;
    }

    /**
     * @return ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getOdplatnoscId() {
        return odplatnoscId;
    }

    /**
     * ODPLATNOSC_DECYZJA_SKLADNIK.ODPLATNOSC_ID
     *
     * @param odplatnoscId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setOdplatnoscId(Long odplatnoscId) {
        this.odplatnoscId = odplatnoscId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        OdplatnoscDecyzjaSkladnikKey other = (OdplatnoscDecyzjaSkladnikKey) that;
        return (this.getDecyzjaOOdplatnosciId() == null ? other.getDecyzjaOOdplatnosciId() == null : this.getDecyzjaOOdplatnosciId().equals(other.getDecyzjaOOdplatnosciId()))
            && (this.getOdplatnoscId() == null ? other.getOdplatnoscId() == null : this.getOdplatnoscId().equals(other.getOdplatnoscId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getDecyzjaOOdplatnosciId() == null) ? 0 : getDecyzjaOOdplatnosciId().hashCode());
        result = prime * result + ((getOdplatnoscId() == null) ? 0 : getOdplatnoscId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", decyzjaOOdplatnosciId=").append(decyzjaOOdplatnosciId);
        sb.append(", odplatnoscId=").append(odplatnoscId);
        sb.append("]");
        return sb.toString();
    }
}
